// This is the C++ header file to control the VRS Recording System
// using your C++ program.
//
// (C) 2004 NCH Swift Sound
//
// It provides the functions used for the commandline appliction for controlling VRS
//
// All the functions provided will apply on the VRS Recording System which
// must be installed in the system prior to using these commands.


#ifndef vrsapi_h
#define vrsapi_h

#include <windows.h>

bool VRSAPIStartRecorder(int nChannelZeroBased);
// Starts the specific channel on the recorder
// The channel is zero based (ie. starts 0..)
// Returns true if it succeeds, false if VRS was not found

bool VRSAPIStartRecorder(int nChannelZeroBased, const char* szFullPathToWaveFile);
// Same as VRSAPIStartRecroder except that the recording wav file path can be specified.

bool VRSAPIStopRecorder(int nChannelZeroBased);
// Stops the specific channel on the recorder
// The channel is zero based (ie. starts 0..)
// Returns true if it succeeds, false if VRS was not found

bool VRSAPIIsRecording(int nChannelZeroBased);
// Returns true if the channel is recording.

void VRSAPISetRecordingData(int nChannelZeroBased, const char* szData, bool bPersists);
// Desired data can be associated with VRS
// The channel is zero based (ie., starts at 0..)
// szData is the data reference i.e., where the desired data is present
// You can search for the desired file in the "find&play" option of the VRS


HWND VRSAPIFindWindow();
// Returns a handle to the main VRS Window (if running)
// If not running returns NULL

HWND VRSAPIRunAndFindWindow();
// If VRS is running returns a handle to the main window
// If not running it runs it first, waits then returns the handle
// If VRS cannot be run returns NULL.


// These are the defines if required

#ifndef MCI_RECORD
#define MCI_RECORD 0x080F
#endif

#ifndef MCI_STOP
#define MCI_STOP 0x0808
#endif

#ifndef MCI_STATUS
#define MCI_STATUS 0x0814
#endif

#ifndef MCI_SET
#define MCI_SET 0x080D
#endif


// Inline functions start here...

inline HWND VRSAPIFindWindow()
{
   return FindWindowEx(NULL, NULL, NULL, TEXT("VRS Recording System"));
}

inline bool VRSAPIStartRecorder(int nChannelZeroBased)
{
   HWND hWndVRS = VRSAPIRunAndFindWindow();
   if (hWndVRS == NULL) { // Run failed
      return false;
   }
   SendMessage(hWndVRS, MCI_RECORD, (WPARAM)nChannelZeroBased, NULL);
   return true;
}

inline bool VRSAPIStartRecorder(int nChannelZeroBased, const char* szFullPathToWaveFile)
{
   HWND hWndVRS = VRSAPIRunAndFindWindow();
   if (hWndVRS == NULL) { // Run failed
     return false;
   }
   ATOM atomExtraInfo = GlobalAddAtom(szFullPathToWaveFile);
   SendMessage(hWndVRS, MCI_RECORD, (WPARAM)nChannelZeroBased,
                   atomExtraInfo);
   GlobalDeleteAtom(atomExtraInfo);
   return true;
}

inline bool VRSAPIStopRecorder(int nChannelZeroBased)
{
   HWND hWndVRS = VRSAPIFindWindow();
   if (hWndVRS == NULL) return false;
   SendMessage(hWndVRS, MCI_STOP, (WPARAM)nChannelZeroBased, NULL);
   return true;
}

inline bool VRSAPIIsRecording(int nChannelZeroBased)
{
   HWND hWndVRS = VRSAPIFindWindow();
   if (hWndVRS == NULL) return false;
   return SendMessage(hWndVRS, MCI_STATUS, (WPARAM)nChannelZeroBased, NULL);
}

#endif
